/*
 * CrudContainer
 * Copyright (C) 2011 by Apaq
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package dk.apaq.crud.core;

import dk.apaq.crud.Crud;
import dk.apaq.filter.Filter;
import dk.apaq.filter.limit.Limit;
import dk.apaq.filter.sort.Sorter;
import java.util.List;

/**
 * An abstract implementation of a <code>Crud.Filterable</code> instance taking care
 * of CrudNotifer logic. An implementing class needs only to call the fire* methods(fx. fireOnRead)
 * and this class will make sure to fire events on the listeners.
 */
public abstract class BaseFilterableCrud<IDT, BT> extends BaseCrud<IDT, BT> implements Crud.Filterable<IDT, BT> {

    /**
     * {@inheritDoc}
     */
    public List<IDT> listIds(Limit limit) {
        return listIds(null, null, limit);
    }

    /**
     * {@inheritDoc}
     */
    public List<IDT> listIds(Filter filter, Sorter sorter) {
        return listIds(filter, sorter, null);
    }
    
    /**
     * {@inheritDoc}
     */
    public List<BT> list(Limit limit) {
        return list(null, null, limit);
    }

    /**
     * {@inheritDoc}
     */
    public List<BT> list(Filter filter, Sorter sorter) {
        return list(filter, sorter, null);
    }

}
